@media all {
    .aa-discord-announcements-header-addition {
        display: block;
    }

    .aa-discord-announcements-announcementtext {
        position: sticky;
        top: 1rem;
    }

    .aa-discord-announcements form label {
        font-weight: normal;
    }

    .aa-discord-announcements form label .form-field-required {
        font-weight: 700;
    }

    .aa-discord-announcements-footer {
        border-top: 1px solid rgb(236 240 241);
        font-size: 85%;
        margin-top: 1rem;
        padding-top: 1rem;
    }

    .template-dark-mode .aa-discord-announcements-footer {
        border-color: rgb(70 69 69);
    }
}
